@@ -28,7 +28,7 @@
 
 package Config::Model::Exception ;
 {
-  $Config::Model::Exception::VERSION = '2.007';
+  $Config::Model::Exception::VERSION = '2.008';
 }
 use warnings ;
 use strict;
@@ -38,8 +38,8 @@ use Exception::Class
   (
    'Config::Model::Exception::Syntax' 
    => { description => 'config error' ,
-	fields      =>  'object' ,
-	description => 'syntax error in configuration file',
+	fields      =>  [qw/object file line/] ,
+	description => 'syntax error',
       },
 
    'Config::Model::Exception::Any' 
@@ -155,14 +155,15 @@ Config::Model::Exception::Internal->Trace(1);
 
 package Config::Model::Exception::Syntax ;
 {
-  $Config::Model::Exception::Syntax::VERSION = '2.007';
+  $Config::Model::Exception::Syntax::VERSION = '2.008';
 }
 
 sub full_message {
     my $self = shift;
 
-    my $obj = $self->object ;
-    my $msg = "File of type ".ref ($obj) ." ";
+    my $fn = $self->file || '?' ;
+    my $line = $self->line || '?' ;
+    my $msg = "File $fn line $line ";
     $msg .= "has a ".$self->description ;
     $msg .= ":\n\t". $self->message."\n";
 
@@ -171,7 +172,7 @@ sub full_message {
 
 package Config::Model::Exception::Any ;
 {
-  $Config::Model::Exception::Any::VERSION = '2.007';
+  $Config::Model::Exception::Any::VERSION = '2.008';
 }
 
 sub full_message {
@@ -203,7 +204,7 @@ sub xpath_message {
 
 package Config::Model::Exception::LoadData ;
 {
-  $Config::Model::Exception::LoadData::VERSION = '2.007';
+  $Config::Model::Exception::LoadData::VERSION = '2.008';
 }
 
 sub full_message {
@@ -223,7 +224,7 @@ sub full_message {
 
 package Config::Model::Exception::Model ;
 {
-  $Config::Model::Exception::Model::VERSION = '2.007';
+  $Config::Model::Exception::Model::VERSION = '2.008';
 }
 
 sub full_message {
@@ -249,7 +250,7 @@ sub full_message {
 
 package Config::Model::Exception::Load ;
 {
-  $Config::Model::Exception::Load::VERSION = '2.007';
+  $Config::Model::Exception::Load::VERSION = '2.008';
 }
 
 sub full_message {
@@ -271,7 +272,7 @@ sub full_message {
 
 package Config::Model::Exception::RestrictedElement ;
 {
-  $Config::Model::Exception::RestrictedElement::VERSION = '2.007';
+  $Config::Model::Exception::RestrictedElement::VERSION = '2.008';
 }
 
 sub full_message {
@@ -291,7 +292,7 @@ sub full_message {
 
 package Config::Model::Exception::UnavailableElement ;
 {
-  $Config::Model::Exception::UnavailableElement::VERSION = '2.007';
+  $Config::Model::Exception::UnavailableElement::VERSION = '2.008';
 }
 
 sub full_message {
@@ -314,7 +315,7 @@ sub full_message {
 
 package Config::Model::Exception::ObsoleteElement ;
 {
-  $Config::Model::Exception::ObsoleteElement::VERSION = '2.007';
+  $Config::Model::Exception::ObsoleteElement::VERSION = '2.008';
 }
 
 sub full_message {
@@ -336,7 +337,7 @@ sub full_message {
 
 package Config::Model::Exception::UnknownElement ;
 {
-  $Config::Model::Exception::UnknownElement::VERSION = '2.007';
+  $Config::Model::Exception::UnknownElement::VERSION = '2.008';
 }
 use Carp;
 
@@ -403,7 +404,7 @@ sub full_message {
 
 package Config::Model::Exception::UnknownId ;
 {
-  $Config::Model::Exception::UnknownId::VERSION = '2.007';
+  $Config::Model::Exception::UnknownId::VERSION = '2.008';
 }
 
 sub full_message {
@@ -432,7 +433,7 @@ sub full_message {
 
 package Config::Model::Exception::WrongType ;
 {
-  $Config::Model::Exception::WrongType::VERSION = '2.007';
+  $Config::Model::Exception::WrongType::VERSION = '2.008';
 }
 
 sub full_message {
@@ -456,7 +457,7 @@ sub full_message {
 
 package Config::Model::Exception::Xml ;
 {
-  $Config::Model::Exception::Xml::VERSION = '2.007';
+  $Config::Model::Exception::Xml::VERSION = '2.008';
 }
 
 sub full_message {
@@ -484,7 +485,7 @@ Config::Model::Exception - Exception mechanism for configuration model
 
 =head1 VERSION
 
-version 2.007
+version 2.008
 
 =head1 SYNOPSIS
 
