@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2011 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -39,6 +39,13 @@
         'description' => 'Package control file. Specifies the most vital (and version-independent) information about the source package and about the binary packages it creates.',
         'config_class_name' => 'Debian::Dpkg::Control'
       },
+      'rules',
+      {
+        'value_type' => 'string',
+        'summary' => 'package build rules',
+        'type' => 'leaf',
+        'description' => 'debian/rules is a makefile containing all intructions required to build a debian package.'
+      },
       'copyright',
       {
         'summary' => 'copyright and license information',
